==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/emr/kotlin/inputs/InstanceFleetInstanceTypeConfigConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emr.kotlin.inputs

import com.pulumi.aws.emr.inputs.InstanceFleetInstanceTypeConfigConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property classification The classification within a configuration.
 * @property properties A map of properties specified within a configuration classification
 */
public data class InstanceFleetInstanceTypeConfigConfigurationArgs(
    public val classification: Output<String>? = null,
    public val properties: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.emr.inputs.InstanceFleetInstanceTypeConfigConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.emr.inputs.InstanceFleetInstanceTypeConfigConfigurationArgs =
        com.pulumi.aws.emr.inputs.InstanceFleetInstanceTypeConfigConfigurationArgs.builder()
            .classification(classification?.applyValue({ args0 -> args0 }))
            .properties(
                properties?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [InstanceFleetInstanceTypeConfigConfigurationArgs].
 */
@PulumiTagMarker
public class InstanceFleetInstanceTypeConfigConfigurationArgsBuilder internal constructor() {
    private var classification: Output<String>? = null

    private var properties: Output<Map<String, String>>? = null

    /**
     * @param value The classification within a configuration.
     */
    @JvmName("dyekmdugpanrndpm")
    public suspend fun classification(`value`: Output<String>) {
        this.classification = value
    }

    /**
     * @param value A map of properties specified within a configuration classification
     */
    @JvmName("fytokdxsqtcglqkc")
    public suspend fun properties(`value`: Output<Map<String, String>>) {
        this.properties = value
    }

    /**
     * @param value The classification within a configuration.
     */
    @JvmName("ksyksrwffhkqryef")
    public suspend fun classification(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.classification = mapped
    }

    /**
     * @param value A map of properties specified within a configuration classification
     */
    @JvmName("apmujqwrnsxcwevc")
    public suspend fun properties(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param values A map of properties specified within a configuration classification
     */
    @JvmName("eeabxgdrtdompcgw")
    public fun properties(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    internal fun build(): InstanceFleetInstanceTypeConfigConfigurationArgs =
        InstanceFleetInstanceTypeConfigConfigurationArgs(
            classification = classification,
            properties = properties,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/emr/kotlin/inputs/InstanceFleetInstanceTypeConfigConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emr.kotlin.inputs

import com.pulumi.aws.emr.inputs.InstanceFleetInstanceTypeConfigConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property classification The classification within a configuration.
 * @property properties A map of properties specified within a configuration classification
 */
public data class InstanceFleetInstanceTypeConfigConfigurationArgs(
    public val classification: Output<String>? = null,
    public val properties: Output<Map<String, String>>? = null,
) : ConvertibleToJava<com.pulumi.aws.emr.inputs.InstanceFleetInstanceTypeConfigConfigurationArgs> {
    override fun toJava(): com.pulumi.aws.emr.inputs.InstanceFleetInstanceTypeConfigConfigurationArgs = com.pulumi.aws.emr.inputs.InstanceFleetInstanceTypeConfigConfigurationArgs.builder()
        .classification(classification?.applyValue({ args0 -> args0 }))
        .properties(
            properties?.applyValue({ args0 ->
                args0.map({ args0 ->
                    args0.key.to(args0.value)
                }).toMap()
            }),
        ).build()
}

/**
 * Builder for [InstanceFleetInstanceTypeConfigConfigurationArgs].
 */
@PulumiTagMarker
public class InstanceFleetInstanceTypeConfigConfigurationArgsBuilder internal constructor() {
    private var classification: Output<String>? = null

    private var properties: Output<Map<String, String>>? = null

    /**
     * @param value The classification within a configuration.
     */
    @JvmName("ysvirsffyeafpldg")
    public suspend fun classification(`value`: Output<String>) {
        this.classification = value
    }

    /**
     * @param value A map of properties specified within a configuration classification
     */
    @JvmName("oihqmsfblvsombwf")
    public suspend fun properties(`value`: Output<Map<String, String>>) {
        this.properties = value
    }

    /**
     * @param value The classification within a configuration.
     */
    @JvmName("ijmqfmoikihdtnjc")
    public suspend fun classification(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.classification = mapped
    }

    /**
     * @param value A map of properties specified within a configuration classification
     */
    @JvmName("dhpnmthsxtodvgis")
    public suspend fun properties(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param values A map of properties specified within a configuration classification
     */
    @JvmName("rsjuooyroshbrfbm")
    public fun properties(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    internal fun build(): InstanceFleetInstanceTypeConfigConfigurationArgs =
        InstanceFleetInstanceTypeConfigConfigurationArgs(
            classification = classification,
            properties = properties,
        )
}
